==> jc-1.4.0.tar.gz: gnu/java/io/ASN1ParsingException.h <==
// public class gnu.java.io.ASN1ParsingException

// class file dependencies
// @dep_class 95647318e434aadc gnu_java_io_ASN1ParsingException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_gnu_java_io_ASN1ParsingException_H_
#define _JC_gnu_java_io_ASN1ParsingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ASN1ParsingException$sub_refs	_jc_gnu_java_io_ASN1ParsingException$sub_refs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs	_jc_gnu_java_io_ASN1ParsingException$sub_nonrefs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$refs	_jc_gnu_java_io_ASN1ParsingException$refs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$nonrefs	_jc_gnu_java_io_ASN1ParsingException$nonrefs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$object	_jc_gnu_java_io_ASN1ParsingException$object;

typedef const struct _jc_gnu_java_io_ASN1ParsingException$vmethods	_jc_gnu_java_io_ASN1ParsingException$vmethods;
typedef const struct _jc_gnu_java_io_ASN1ParsingException$vtable	_jc_gnu_java_io_ASN1ParsingException$vtable;
typedef const struct _jc_gnu_java_io_ASN1ParsingException$vtype	_jc_gnu_java_io_ASN1ParsingException$vtype;

// Constructors
extern void _jc_gnu_java_io_ASN1ParsingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_ASN1ParsingException$object *);
extern void _jc_gnu_java_io_ASN1ParsingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_io_ASN1ParsingException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_io_ASN1ParsingException$vmethods {
};

// Vtable
struct _jc_gnu_java_io_ASN1ParsingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_io_ASN1ParsingException$vmethods	gnu_java_io_ASN1ParsingException;
};

// Vtype
struct _jc_gnu_java_io_ASN1ParsingException$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ASN1ParsingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ASN1ParsingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ASN1ParsingException$refs {
    _jc_gnu_java_io_ASN1ParsingException$sub_refs	gnu_java_io_ASN1ParsingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ASN1ParsingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs	gnu_java_io_ASN1ParsingException;
};

// Object instance structure
struct _jc_gnu_java_io_ASN1ParsingException$object {
	_jc_gnu_java_io_ASN1ParsingException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ASN1ParsingException$vtype	*vtype;
	_jc_gnu_java_io_ASN1ParsingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ASN1ParsingException$vtype _jc_gnu_java_io_ASN1ParsingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ASN1ParsingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ASN1ParsingException$class_object;

#endif	/* _JC_gnu_java_io_ASN1ParsingException_H_ */

==> jc-1.4.6.tar.gz: gnu/java/io/ASN1ParsingException.h <==
// public class gnu.java.io.ASN1ParsingException

// class file dependencies
// @dep_class 95647318e434aadc gnu_java_io_ASN1ParsingException
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_gnu_java_io_ASN1ParsingException_H_
#define _JC_gnu_java_io_ASN1ParsingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_io_ASN1ParsingException$sub_refs	_jc_gnu_java_io_ASN1ParsingException$sub_refs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs	_jc_gnu_java_io_ASN1ParsingException$sub_nonrefs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$refs	_jc_gnu_java_io_ASN1ParsingException$refs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$nonrefs	_jc_gnu_java_io_ASN1ParsingException$nonrefs;
typedef struct _jc_gnu_java_io_ASN1ParsingException$object	_jc_gnu_java_io_ASN1ParsingException$object;

typedef const struct _jc_gnu_java_io_ASN1ParsingException$vmethods	_jc_gnu_java_io_ASN1ParsingException$vmethods;
typedef const struct _jc_gnu_java_io_ASN1ParsingException$vtable	_jc_gnu_java_io_ASN1ParsingException$vtable;
typedef const struct _jc_gnu_java_io_ASN1ParsingException$vtype	_jc_gnu_java_io_ASN1ParsingException$vtype;

// Constructors
extern void _jc_gnu_java_io_ASN1ParsingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_io_ASN1ParsingException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_io_ASN1ParsingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_io_ASN1ParsingException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_io_ASN1ParsingException$vmethods {
};

// Vtable
struct _jc_gnu_java_io_ASN1ParsingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_gnu_java_io_ASN1ParsingException$vmethods	gnu_java_io_ASN1ParsingException;
};

// Vtype
struct _jc_gnu_java_io_ASN1ParsingException$vtype {
	_jc_type			type;
	_jc_gnu_java_io_ASN1ParsingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_io_ASN1ParsingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_io_ASN1ParsingException$refs {
    _jc_gnu_java_io_ASN1ParsingException$sub_refs	gnu_java_io_ASN1ParsingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_io_ASN1ParsingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_gnu_java_io_ASN1ParsingException$sub_nonrefs	gnu_java_io_ASN1ParsingException;
};

// Object instance structure
struct _jc_gnu_java_io_ASN1ParsingException$object {
	_jc_gnu_java_io_ASN1ParsingException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_io_ASN1ParsingException$vtype	*vtype;
	_jc_gnu_java_io_ASN1ParsingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_io_ASN1ParsingException$vtype _jc_gnu_java_io_ASN1ParsingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_io_ASN1ParsingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_io_ASN1ParsingException$class_object;

#endif	/* _JC_gnu_java_io_ASN1ParsingException_H_ */
